package com.ruoyi.system.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Hydd;
import com.ruoyi.system.service.IHyddService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会议地点Controller
 * 
 * @author ruoyi
 * @date 2024-10-30
 */
@RestController
@RequestMapping("/system/hydd")
public class HyddController extends BaseController
{
    @Autowired
    private IHyddService hyddService;

    /**
     * 查询会议地点列表
     */
    //@PreAuthorize("@ss.hasPermi('system:hydd:list')")
    @GetMapping("/list")
    public TableDataInfo list(Hydd hydd)
    {
//        startPage();
        List<Hydd> list = hyddService.selectHyddList(hydd);

        List<String> qyList = list.stream().map(Hydd::getQy).distinct().collect(Collectors.toList());
        List<Hydd> relist=new ArrayList<>();
        Long i=0L;
        for(String qy:qyList){
            Hydd dd=new Hydd();
            dd.setDdmc(qy);
            dd.setText(qy);
            dd.setId(i++);
            List<Hydd> collect = list.stream().filter(item -> item.getQy().equals(qy)).collect(Collectors.toList());
            dd.setChildren(collect);
            relist.add(dd);
        }
        return getDataTable(relist);
    }



    /**
     * 导出会议地点列表
     */
    //@PreAuthorize("@ss.hasPermi('system:hydd:export')")
    @Log(title = "会议地点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Hydd hydd)
    {
        List<Hydd> list = hyddService.selectHyddList(hydd);
        ExcelUtil<Hydd> util = new ExcelUtil<Hydd>(Hydd.class);
        util.exportExcel(response, list, "会议地点数据");
    }

    /**
     * 获取会议地点详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:hydd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(hyddService.selectHyddById(id));
    }

    /**
     * 新增会议地点
     */
    //@PreAuthorize("@ss.hasPermi('system:hydd:add')")
    @Log(title = "会议地点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Hydd hydd)
    {
        return toAjax(hyddService.insertHydd(hydd));
    }

    /**
     * 修改会议地点
     */
    //@PreAuthorize("@ss.hasPermi('system:hydd:edit')")
    @Log(title = "会议地点", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Hydd hydd)
    {
        return toAjax(hyddService.updateHydd(hydd));
    }

    /**
     * 删除会议地点
     */
    //@PreAuthorize("@ss.hasPermi('system:hydd:remove')")
    @Log(title = "会议地点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(hyddService.deleteHyddByIds(ids));
    }
}
